// Version KEAterm 3.10 $RCSfile: apxmouse.ktm,v $ $Revision: 1.1 $
// ============================================================================
// ApxMouse:    This Macro provides Mouse support to APPX screens.  Running
//              this macro is optional.  It will perform the following tasks:
//
//  [Send Options]
//              Clicking the mouse while pointing to the numeric tag for an
//              option will cause the macro to send the appropriate key
//              sequences to invoke the option.  The format of the tag needs
//              to be " #) " or " ##) ".  Other pre-defined tags have special
//              meaning such as "RETURN".  This macro will call "ApxOpt.ktm"
//              to resolve the translation between the screen tag and option
//              sequence.  Refer to this supporting macro for a complete list
//              of supported screen tags.
//
//  [Hot Spots]
//              This macro has several regions of the screen defined as Hot 
//              Spots.  Anytime you click on these regions, you get one of
//              the following pre-defined actions.
//
//              1) "Mode:" will pop up a Dialog Box to allow selection of
//                 a new data entry mode. (Add,Delete,Inquiry,Change)
//              2) "Row 22,Col  1-20" will send a "PreviousScreen" sequence.
//              3) "Row 22,Col 21-40" will send a "Return" sequence.
//              4) "Row 22,Col 41-60" will send an "End" sequence.
//              5) "Row 22,Col 61-80" will send a "NextScreen" sequence.
//
//  [Move Cursor]
//              Anytime the mouse is clicked in the terminal window and none
//              of the above conditions are true, the cursor is positioned
//              to the mouse location.
//
// ============================================================================

//
//  ParseWord:  This function will extract the "Word" that was clicked.
//  ScreenLoc[] is an Array structure consisting of Page, Row, & Column.
//

Function ParseWord(ScreenLoc)

    TextLine = Screen(ScreenLoc.Page,ScreenLoc.Row,1,80)

    WorkLoc  = ScreenLoc
    While (SubStr(TextLine,WorkLoc.Col,2) <> "  ")       // Find Start of Word
    and   (WorkLoc.Col > 0                      )
        WorkLoc.Col = WorkLoc.Col - 1
    End
    WorkLoc.Col = WorkLoc.Col + 2
    StartCol = WorkLoc.Col

	 WorkLoc = ScreenLoc
    While (SubStr(TextLine,WorkLoc.Col,1) <> " ")       // Find End of Word
    and   (WorkLoc.Col < 81                     )
        WorkLoc.Col = WorkLoc.Col + 1
    End
    WorkLoc.Col = WorkLoc.Col - 1
    StopCol = WorkLoc.Col
        
    WordSize = StopCol - StartCol + 1
    ParsedWord = SubStr(TextLine,StartCol,WordSize)     // Extract Word

    Return ParsedWord
End

//
//  SendRepeat: This function sends SendString, SendCount times.
//

Function SendRepeat(SendString,SendCount)
    While SendCount > 0
        SendKey(SendString)
        SendCount = SendCount - 1
    End
End

//
//  MoveCursor: This function sends the sequences needed to move the cursor
//  OldLoc[] & NewLoc[] are array structures consisting of Page, Row, & Column
//

Function MoveCursor(OldLoc, NewLoc)
    SendCount = NewLoc.Row - OldLoc.Row                 //  Adjust Row
    If SendCount < 0
        SendString = AppxKey["CursorUp"]
        SendCount  = - SendCount
    Else
        SendString = AppxKey["CursorDown"]
    End
    SendRepeat(SendString,SendCount)

    SendCount = NewLoc.Col - OldLoc.Col                 //  Adjust Column
    If SendCount < 0
        SendString = AppxKey["CursorLeft"]
        SendCount = - SendCount
    Else
        SendString = AppxKey["CursorRight"]
    End
    SendRepeat(SendString,SendCount)
End

//
//  MAIN logic section:  Execution starts here.
//  MouseLoc & CurrentLoc: Array structures containing Page, Row & Column
//  

    MouseLoc.Page = Arg[ 1 ]
    MouseLoc.Row  = Arg[ 2 ]
    MouseLoc.Col  = Arg[ 3 ] + Arg[ 4 ]

    If MouseLoc.Row = 22                                // Hot Spot Mapping
        If MouseLoc.Col < 20
            SendKey(AppxKey["PreviousScreen"])
        elseif MouseLoc.Col > 60
            SendKey(AppxKey["NextScreen"])
        elseif MouseLoc.Col < 40
            SendKey(AppxKey["Return"])
        elseif MouseLoc.Col > 40
            SendKey(AppxKey["End"])
        End
    Else
        ParsedWord = ParseWord( MouseLoc )
        If ApxOpt( ParsedWord ) = 0                 // Send Options
            CurrentLoc = GetCursor( )               // No Options? Move Cursor
            MoveCursor( CurrentLoc , MouseLoc )
        End
    End

//  [End of Macro]
